# pyaibox

A Python Toolbox.

You can install and test ``pyaibox`` by:

```bash
pip install pyaibox
import pyaibox as tb
print(tb.__version__)
```

Please see [pyaibox's documentation](http://iridescent.ink/pyaibox) for using details.
